
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v5.029.
use strict;
use warnings;

use Module::Build 0.28;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.28"
  },
  "configure_requires" => {
    "Module::Build" => "0.28"
  },
  "dist_abstract" => "Manage your datebase schema via checksums",
  "dist_author" => [
    "Thomas Klausner <domm\@cpan.org>",
    "Maro\x{161} Koll\x{e1}r <maros\@cpan.org>",
    "Klaus Ita <koki\@worstofall.com>"
  ],
  "dist_name" => "DBIx-SchemaChecksum",
  "dist_version" => "1.102",
  "license" => "perl",
  "module_name" => "DBIx::SchemaChecksum",
  "recommends" => {},
  "recursive_test_files" => 1,
  "requires" => {
    "Carp" => 0,
    "DBI" => 0,
    "Data::Dumper" => 0,
    "Digest::SHA1" => 0,
    "File::Find::Rule" => 0,
    "File::HomeDir" => 0,
    "IO::Prompt::Tiny" => 0,
    "Moose" => 0,
    "Moose::Role" => 0,
    "Moose::Util::TypeConstraints" => 0,
    "MooseX::App" => "1.21",
    "MooseX::App::Command" => 0,
    "Path::Class" => 0,
    "Try::Tiny" => 0,
    "namespace::autoclean" => 0,
    "perl" => "5.010",
    "strict" => 0,
    "utf8" => 0,
    "warnings" => 0
  },
  "script_files" => [
    "bin/scs.pl",
    "bin/dbchecksum"
  ],
  "test_requires" => {
    "DBD::SQLite" => "1.35",
    "File::Copy" => 0,
    "File::Spec" => 0,
    "File::Temp" => 0,
    "Module::Pluggable" => 0,
    "Test::More" => 0,
    "Test::Most" => 0,
    "Test::Trap" => 0,
    "lib" => 0
  }
);


my %fallback_build_requires = (
  "DBD::SQLite" => "1.35",
  "File::Copy" => 0,
  "File::Spec" => 0,
  "File::Temp" => 0,
  "Module::Build" => "0.28",
  "Module::Pluggable" => 0,
  "Test::More" => 0,
  "Test::Most" => 0,
  "Test::Trap" => 0,
  "lib" => 0
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);

$build->create_build_script;
